package com.jjt.biz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.enums.BusinessType;
import com.jjt.biz.domain.KeyInfo;
import com.jjt.biz.service.IKeyInfoService;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.common.core.page.TableDataInfo;

/**
 * 关键字Controller
 * 
 * @author ruoyi
 * @date 2023-07-06
 */
@RestController
@RequestMapping("/biz/keyInfo")
public class KeyInfoController extends BaseController
{
    @Autowired
    private IKeyInfoService keyInfoService;

    /**
     * 查询关键字列表
     */
    @PreAuthorize("@ss.hasPermi('biz:keyInfo:list')")
    @GetMapping("/list")
    public TableDataInfo list(KeyInfo keyInfo)
    {
        startPage();
        List<KeyInfo> list = keyInfoService.selectKeyInfoList(keyInfo);
        return getDataTable(list);
    }

    /**
     * 导出关键字列表
     */
    @PreAuthorize("@ss.hasPermi('biz:keyInfo:export')")
    @Log(title = "关键字", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, KeyInfo keyInfo)
    {
        List<KeyInfo> list = keyInfoService.selectKeyInfoList(keyInfo);
        ExcelUtil<KeyInfo> util = new ExcelUtil<KeyInfo>(KeyInfo.class);
        util.exportExcel(response, list, "关键字数据");
    }

    /**
     * 获取关键字详细信息
     */
    @PreAuthorize("@ss.hasPermi('biz:keyInfo:query')")
    @GetMapping(value = "/{keyId}")
    public AjaxResult getInfo(@PathVariable("keyId") Long keyId)
    {
        return success(keyInfoService.selectKeyInfoByKeyId(keyId));
    }

    /**
     * 新增关键字
     */
    @PreAuthorize("@ss.hasPermi('biz:keyInfo:add')")
    @Log(title = "关键字", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody KeyInfo keyInfo)
    {
        return toAjax(keyInfoService.insertKeyInfo(keyInfo));
    }

    /**
     * 修改关键字
     */
    @PreAuthorize("@ss.hasPermi('biz:keyInfo:edit')")
    @Log(title = "关键字", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody KeyInfo keyInfo)
    {
        return toAjax(keyInfoService.updateKeyInfo(keyInfo));
    }

    /**
     * 删除关键字
     */
    @PreAuthorize("@ss.hasPermi('biz:keyInfo:remove')")
    @Log(title = "关键字", businessType = BusinessType.DELETE)
	@DeleteMapping("/{keyIds}")
    public AjaxResult remove(@PathVariable Long[] keyIds)
    {
        return toAjax(keyInfoService.deleteKeyInfoByKeyIds(keyIds));
    }
}
